@@ -41,7 +41,7 @@ def make_yaml_valid_dict(input: list) -> dict:
 
     # yaml compatible strings are of the form Key:Value
     yamlstr = YAML_SEPARATOR.join(input)
-    runtime_modifications = yaml.load(yamlstr, Loader=yaml.FullLoader)
+    runtime_modifications = yaml.load(yamlstr, Loader=yaml.SafeLoader)
 
     return runtime_modifications
 
@@ -140,7 +140,7 @@ def verify_config_colors(config):
 def load_config(config_path):
     """Tries to load a config file from YAML."""
     with open(config_path) as f:
-        return yaml.load(f, Loader=yaml.FullLoader)
+        return yaml.load(f, Loader=yaml.SafeLoader)
 
 
 def is_config_json(config_path):
